@@ -33,9 +33,10 @@
 #  define MESSAGEVIEWER_DEPRECATED_NO_EXPORT MESSAGEVIEWER_NO_EXPORT MESSAGEVIEWER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MESSAGEVIEWER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MESSAGEVIEWER_NO_DEPRECATED
+#    define MESSAGEVIEWER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
